<?php
/**
 * A factory class for message type handlers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class MessageTypeHandlerFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton message type handler instance. If an instance is
	 * found in registry, it will be returned, else a new instance is created
	 * and stored in the same registry entry.
	 *
	 * @param	$messageType		Message type to create an object from
	 * @return	$handlerInstance	A message type handler instance
	 */
	public static final function createMessageTypeHandlerInstance ($messageType) {
		// Do we have an instance in the registry?
		if (Registry::getRegistry()->instanceExists('message_type_' . $messageType . '_handler')) {
			// Then use this instance
			$handlerInstance = Registry::getRegistry()->getInstance('message_type_' . $messageType . '_handler');
		} else {
			// Now prepare the tags instance
			$handlerInstance = self::createObjectByConfiguredName('message_type_' . $messageType . '_handler_class');

			// Set the instance in registry for further use
			Registry::getRegistry()->addInstance('message_type_' . $messageType . '_handler', $handlerInstance);
		}

		// Return the instance
		return $handlerInstance;
	}
}

// [EOF]
?>
