<?php
/**
 * A RequestNodeListTag filter for packages
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PackageRequestNodeListTagFilter extends BaseNodeFilter implements FilterablePackage {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Init XML nodes array which contains the required data
		$this->dataXmlNodes = array(
			XmlRequestNodeListTemplateEngine::REQUEST_DATA_ACCEPTED_OBJECT_TYPES => '',
			XmlRequestNodeListTemplateEngine::REQUEST_DATA_SESSION_ID            => '',
		);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public final static function createPackageRequestNodeListTagFilter () {
		// Get a new instance
		$filterInstance = new PackageRequestNodeListTagFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Please don't call this method
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Processes the given raw message content.
	 *
	 * @param	$messageData		Raw message data array
	 * @param	$packageInstance	An instance of a Receivable class
	 * @return	void
	 */
	public function processMessage (array $messageData, Receivable $packageInstance) {
		// Process messasge generic
		$this->genericProcessMessage('request_node_list', $messageData, $packageInstance);
	}

	/**
	 * Post-processes the stacked message. Do not call popNamed() as then no
	 * other class can process the message.
	 *
	 * @param	$packageInstance	An instance of a Receivable class
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function postProcessMessage (Receivable $packageInstance) {
		// Please don't call this method
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}
}

// [EOF]
?>
