<?php
/**
 * A TaskHandlerInitializer filter for crunchers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2011 - 2014 Cruncher Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CruncherTaskHandlerInitializerFilter extends BaseCruncherFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createCruncherTaskHandlerInitializerFilter () {
		// Get a new instance
		$filterInstance = new CruncherTaskHandlerInitializerFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If the filter chain needs to be interrupted
	 * @todo	5% done
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get cruncher instance
		//$cruncherInstance = Registry::getRegistry()->getInstance('cruncher');

		// Get a new task handler instance
		$handlerInstance = ObjectFactory::createObjectByConfiguredName('task_handler_class');

		// Put the task handler in registry
		Registry::getRegistry()->addInstance('task_handler', $handlerInstance);

		// Register all tasks:
		//
		// 1) A task for fetching WUs (work units) or test units
		$taskInstance = ObjectFactory::createObjectByConfiguredName('cruncher_work_unit_fetcher_task_class');
		$handlerInstance->registerTask('cruncher_work_unit_fetcher', $taskInstance);

		/*
		 * 2) A task for generating test units, a if() block could be placed
		 *    around this but that would make this method look a little ugly and
		 *    even more when more "temporary" tasks should be registered.
		 */
		$taskInstance = ObjectFactory::createObjectByConfiguredName('cruncher_test_unit_producer_task_class');
		$handlerInstance->registerTask('cruncher_test_unit_producer', $taskInstance);

		/*
		 * 3) A task for generating keys based on the generated test unit. This
		 *    task will only be executed if the state of the cruncher is one of
		 *    these: 'virgin'.
		 */
		$taskInstance = ObjectFactory::createObjectByConfiguredName('cruncher_key_producer_task_class');
		$handlerInstance->registerTask('cruncher_key_producer', $taskInstance);
	}
}

// [EOF]
?>
